:mod:`API`
 ----------------------------

 Example For Autogenerated API Documentation
 ===========================================

 .. automodule:: xapres_package.dummy
    :members:
    :undoc-members:
    :show-inheritance: